PPS.fit() returns the fit of a PPS distribution to real data, allowing the scale parameter to be held fixed if desired.PPS.fit(x, estim.method = "MLE", sigma = NULL, start, Pareto = FALSE, ...)NULL, the parameter is estimated.TRUE.PPSfit Object, a list with"LMOM" the function also returns details about the convergence of the numerical method involved (convergence value).estim.method = "MLE". The numerical algorithm to search the optimum is the ``Nelder-Mead'' method implemented in the optim function, considering as initial values those given in the start argument or, if it is missing, those provided by the OLS method.
A different approximation of the maximum likelihood estimates is given by estim method = "iMLE"; it is an iterative methodology where optimize() function provides the optimum scale parameter value, while the uniroot() function solve normal equations for that given scale parameter.
The regression estimates ("OLS") searchs an optimum scale value (in a OLS criterion) by the optimize() function. Then the rest of the parameters are estimated also by OLS, as appears in Sarabia and Prieto (2009).
In the L-moments method ("LMOM") estimates are obtained searching parameters that equal the first three sample and theoretical L-moments by means of the ``Nelder-Mead'' algorithm implemented in optim(); the initial values are given in the start argument or, if it is missing, provided by the "iMLE".coef.PPSfit, print.PPSfit, plot.PPSfit, GoF.PPSfitx <- rPPS(50, 1.2, 100, 2.3)
fit <- PPS.fit(x)
print(fit)
coef(fit)
se.PPSfit(fit, k = 50, show.iters = FALSE)
logLik(fit)
par(mfrow=c(2,2))
plot(fit)
GoF.PPSfit(fit, k = 50, show.iters = FALSE)Run the code above in your browser using DataLab